@@ -59,13 +59,8 @@ sub verify {
 
         isa_ok( my $entry = $dir->live_objects->object_to_entry($obj), "KiokuDB::Entry" );
 
-        my $updated = $entry->clone(
-            data => {
-                %{ $entry->data },
-                age => 1841,
-            },
-            prev => $entry,
-        );
+        my $updated = $entry->clone( prev => $entry );
+        $updated->data->{age} = 1841;
 
         is( $obj->age, 10, "age attr" );
 
@@ -73,8 +68,6 @@ sub verify {
 
         is( $obj->age, 10, "age attr not updated even though it was written" );
 
-        local $TODO = "refresh not yet implemented";
-
         lives_ok { $dir->refresh($obj) } "no error in refresh";
 
         is( $obj->age, 1841, "age updated" );
